function Q3_trend
%-------------------------------------------------------------------------
%Function to display and correct mag data collected with a walking mag and
% a base station mag
% Greg Nieuwenhuis, February 2009


% Settings:
%   high_limit/low_limit - change to remove extranneous data in the
%                          corrected data
%   uncor_high/ uncor_low - change to remove really small or really large
%                           data points which may affect the display of the
%                           grid
%   method   -  change to set how griddata grids the data 
%------------------------------------------------------------------------

close all
clear all

high_limit=2750; %cutoff factors for corrected data
low_limit=-4500;

uncor_high=60000; % cutoff factors for the uncorrected data
uncor_low=52500;

method='v4'; % can be 'linear', 'cubic', 'nearest', 'v4'


base_dat=load('base.txt'); %first column time
                          %second column nT

walk_dat=load('Walk.txt');  % First column time
                              % second column latitude
                              % third column longitude
                              % 4th column nT

gps=load('gps_paths_edit.txt');% First column time
                              % second column latitude
                              % third column longitude
                              % 4th column N/A nT
                             

% Change time from HHMMSS to sec
base_str(:,:)=num2str(base_dat(:,1));
walk_str(:,:)=num2str(walk_dat(:,1));

len_base=length(base_str(:,1));
len_walk=length(walk_str(:,1));

for i=1:len_base
    
    base_sec(i,1)=str2num(base_str(i,5:6))+(str2num(base_str(i,3:4))*60)+(str2num(base_str(i,1:2))*60*60);
    
end

clear i

for i=1:len_walk
    
    walk_sec(i,1)=str2num(walk_str(i,5:6))+(str2num(walk_str(i,3:4))*60)+(str2num(walk_str(i,1:2))*60*60);
    
end

clear i
temp1(:,1)=base_sec(:,1);
temp2(:,1)=walk_sec(:,1);
temp1(:,2)=base_dat(:,2);
for i=2:4
    temp2(:,i)=walk_dat(:,i);
end

clear base_dat walk_dat

base_dat=temp1;
walk_dat=temp2;

clear temp1 temp2 i

% Change LAT/LONG into UTM
[walk_dat(:,3),walk_dat(:,2),zone]=deg2utm(walk_dat(:,2), walk_dat(:,3));
[gps(:,3),gps(:,2),zone]=deg2utm(gps(:,2),gps(:,3));



% Make equal spaced vectors for gridding
X(1,:)=[min(walk_dat(:,3)):3:max(walk_dat(:,3))];

Y(:,1)=[min(walk_dat(:,2)):3:max(walk_dat(:,2))];


%-------------------Correcting--------------------------------------


%Find when and with which instrument to start correcting
if walk_dat(1,1) < base_dat(1,1)
    flag=1;
    display('walking mag started first')
elseif walk_dat(1,1) > base_dat(1,1)
    int=find(base_dat(:,1)==walk_dat(1,1));
    flag=2;
    display('base mag started first')
else
    display('Error, somethings wrong with the time????')
end

if walk_dat(length(walk_dat(:,1)),1) < base_dat(length(base_dat(:,1)),1)
    finisher = walk_dat(length(walk_dat(:,1)),1);% walking mag stopped first
    flag2=1;
    display('walking mag stopped first')
elseif walk_dat(length(walk_dat(:,1)),1) > base_dat(length(base_dat(:,1)),1)
    finisher = base_dat(length(base_dat(:,1)),1);% base mag stopped first
    flag2=2;
    display('Base mag stopped first')
end


%interpolate between data points in order to correct the data 
xi=[1,base_dat(1,1):1:base_dat(length(base_dat(:,1)),1)];
yi(:,1) = interp1(base_dat(:,1),base_dat(:,2),xi(1,:),'linear');


%find which data points line up in time for correcting
base_cor=yi(2:length(yi),1);
time_cor=xi(1,2:length(xi));

counter=1;
for j=1:length(time_cor)
    temp=find(time_cor(1,j) == walk_dat(:,1));
    if isempty(temp)
        clear temp;
    else
        a_walk(counter,1)=temp;
        a_cor(counter,1)=j;
        counter = counter +1;
        clear temp;
    end
end
clear temp


% Correct the data (subtract the base mag from the walking mag 
i=1;
for i=1:length(a_walk);
    
    cor(i,4)=walk_dat(a_walk(i,1),4)-base_cor(a_cor(i,1),1);
    cor(i,2)=walk_dat(a_walk(i,1),2);
    cor(i,3)=walk_dat(a_walk(i,1),3);
    cor(i,1)=walk_dat(a_walk(i,1),1);
    
end


%Grid the corrected data
[XI2,YI2,Z2]=griddata(cor(:,3),cor(:,2),cor(:,4),X,Y, method);

%PLot the corrected data
figure
pcolor(X,Y,Z2);
shading interp
hold on;
plot(cor(:,3),cor(:,2),'r+')
caxis([low_limit high_limit]);
title('Base Station Corrected (nT)')
xlabel('Eastings (m)')
ylabel('Northings (m)')
colorbar
hold on
plot(gps(:,3),gps(:,2),'k')
hold on
f=2;
x_p(1:length(Y))=X(f);
plot(x_p,Y,'ko')

ans1(:,1)=YI2(:,2);
ans1(:,2)=Z2(:,2);
save('profile.txt','ans1','-ascii','-tabs')

ans(:,1)=1:length(Z2(:,2));
ans(:,2)=YI2(:,2)-YI2(1,2);
ans(:,3)=zeros(length(Z2(:,2)),1);
ans(:,4)=Z2(:,2);
save('fit.txt','ans','-ascii','-tabs')

figure 
plot(YI2(:,2),Z2(:,2))
title('Selected Magnetic Profile (South to North)')
xlabel('Northings (m)')
ylabel('Corrected Field (nT)')

fit=polyfit(ans1(:,1),ans1(:,2),1);

best=polyval(fit,ans1(:,1));

figure
plot(ans1(:,1),ans1(:,2),'k')
hold on;
plot(ans1(:,1),best,'b')
xlabel('Northing (m)')
ylabel('Corrected Field (nT)')
legend('Measured Field','Linear Trend')
title('Pre Trend Removal')

corr=ans1(:,2)-best;

figure
plot(ans1(:,1),corr,'k')
hold on
plot(ans1(:,1),zeros(length(ans1(:,1))),'b')
legend('Data without trend','Zero Line')
xlabel('Northings (m)')
ylabel('Corrected Field (nT)')
title('Post Trend Removal')